from typing import List
from name_genie.common import data_place_suffix, data_shared_place
from name_genie.util import to_str
import random

__all__ = ['get_places']


def get_places(count: int = 10,
               length: int | None = None,
               stem: str | None = None,
               suffix: str | None = None) -> List[str]:
    """
    生成地点
    生成算法：(stem) + (suffix)
    :param count: 数量
    :param length: 词干长度
    :param stem: 词干
    :param suffix: 后缀
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        suffix2 = suffix
        if stem2 is None:
            stem2 = ''
            length2 = length
            if length2 is None:
                length2 = 2 if random.random() > 0.3 else 1
            for j in range(length2):
                stem2 += random.choice(data_shared_place)
        if suffix2 is None:
            suffix2 = random.choice(data_place_suffix)
        name = to_str(stem2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_places())



from typing import List
from name_genie.common import data_nation_interfix, data_nation_suffix, data_shared_place
from name_genie.util import to_str
import random

__all__ = ['get_nations']


def get_nations(count: int = 10,
                length: int | None = None,
                stem: str | None = None,
                interfix: str | None = None,
                suffix: str | None = None) -> List[str]:
    """
    生成国家
    生成算法：(stem) + [interfix] + (suffix)
    :param count: 数量
    :param length: 词干长度
    :param stem: 词干
    :param interfix: 连接
    :param suffix: 后缀
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        interfix2 = interfix
        suffix2 = suffix
        if suffix2 is None:
            suffix2 = random.choice(data_nation_suffix)
        if interfix2 is None and random.random() > 0.8:
            interfix2 = random.choice(data_nation_interfix)
        suffix2 = to_str(interfix2) + to_str(suffix2)

        if stem2 is None:
            stem2 = ''
            length2 = length
            if length2 is None:
                length2 = 2 if random.random() > 0.5 else 1
                if len(suffix2) == 2:
                    length2 = 2
            for j in range(length2):
                stem2 += random.choice(data_shared_place)

        name = to_str(stem2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_nations())



from typing import List
from name_genie.common import data_creature_interfix, data_creature_suffix, data_shared_action, data_shared_adj, data_shared_creature, data_shared_dao, data_shared_element, data_shared_gesture, data_shared_thing
from name_genie.util import to_str
import random

__all__ = ['get_creatures']

stems = data_shared_action + data_shared_adj + data_shared_creature + data_shared_dao + data_shared_element + data_shared_gesture + data_shared_thing


def get_creatures(count: int = 10,
                  stem: str | None = None,
                  interfix: str | None = None,
                  suffix: str | None = None) -> List[str]:
    """
    生成生灵
    生成算法：(stem) + [(interfix)] + (suffix)
    :param count: 数量
    :param stem: 词干
    :param interfix: 连接
    :param suffix: 后缀
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        interfix2 = interfix
        suffix2 = suffix
        if stem2 is None:
            stem2 = random.choice(stems)
        if interfix2 is None and random.random() > 0.8:
            interfix2 = random.choice(data_creature_interfix)
        if suffix2 is None:
            suffix2 = random.choice(data_creature_suffix)
        name = to_str(stem2) + to_str(interfix2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_creatures())



from name_genie.alchemy import *
from name_genie.book import *
from name_genie.clan import *
from name_genie.creature import *
from name_genie.dao import *
from name_genie.material import *
from name_genie.name import *
from name_genie.nation import *
from name_genie.place import *
from name_genie.skill import *
from name_genie.talisman import *



from typing import List
from name_genie.common import data_name_prefix, data_name_interfix, data_name_male_suffix, data_name_female_suffix
from name_genie.util import to_str
import random

__all__ = ['get_names']


interfixes = data_name_male_suffix + data_name_female_suffix + data_name_interfix

suffixes = data_name_male_suffix + data_name_female_suffix


def get_names(count: int = 10,
              gender: int | None = None,
              length: int | None = None,
              prefix: str | None = None,
              suffix: str | None = None) -> List[str]:
    """
    生成名字
    生成算法：(prefix) + (suffix)
    :param count: 数量
    :param gender: 性别: 1 - 男; 2 - 女
    :param length: 名字长度
    :param prefix: 前缀
    :param suffix: 后缀
    :return:
    """
    names: List[str] = []
    for i in range(count):
        gender2 = gender
        length2 = length
        prefix2 = prefix
        suffix2 = suffix
        if prefix2 is None:
            prefix2 = random.choice(data_name_prefix)
        if suffix2 is None:
            suffix2 = ''
            if length2 is None:
                length2 = 2 if random.random() > 0.5 else 1
            if length2 == 2:
                if gender2 == 1:
                    suffix2 += random.choice(data_name_male_suffix)
                elif gender2 == 2:
                    suffix2 += random.choice(data_name_female_suffix)
                else:
                    suffix2 += random.choice(interfixes)
                length2 -= 1
            for j in range(length2):
                if gender2 == 1:
                    suffix2 += random.choice(data_name_male_suffix)
                elif gender2 == 2:
                    suffix2 += random.choice(data_name_female_suffix)
                else:
                    suffix2 += random.choice(interfixes)
        name = to_str(prefix2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_names())



from typing import List
from name_genie.common import data_dao_stem, data_dao_male_suffix, data_dao_female_suffix, data_shared_dao, data_shared_thing, data_shared_adj, data_shared_number
from name_genie.util import to_str
import random

__all__ = ['get_daos']


stems = data_dao_stem + data_shared_dao + data_shared_thing + data_shared_adj + data_shared_number
suffixes = data_dao_male_suffix + data_dao_female_suffix


def get_daos(count: int = 10,
             gender: int | None = None,
             stem: str | None = None,
             suffix: str | None = None) -> List[str]:
    """
    生成道号
    生成算法：(stem) + (suffix)
    :param count: 数量
    :param gender: 性别: 1 - 男; 2 - 女
    :param stem: 词干
    :param suffix: 后缀
    :return:
    """
    names: List[str] = []
    for i in range(count):
        gender2 = gender
        stem2 = stem
        suffix2 = suffix
        if stem2 is None:
            stem2 = random.choice(stems)
        if suffix2 is None:
            if gender2 == 1:
                suffix2 = random.choice(data_dao_male_suffix)
            elif gender2 == 2:
                suffix2 = random.choice(data_dao_female_suffix)
            else:
                suffix2 = random.choice(suffixes)
        name = to_str(stem2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_daos())



from typing import List
from name_genie.common import data_alchemy_suffix,data_shared_action, data_shared_color, data_shared_dao, data_shared_element, data_shared_number
from name_genie.util import to_str
import random

__all__ = ['get_alchemies']


stems = data_shared_action + data_shared_color + data_shared_dao + data_shared_element + data_shared_number


def get_alchemies(count: int = 10,
                  stem: str | None = None,
                  suffix: str | None = None) -> List[str]:
    """
    生成丹药
    生成算法：(stem) + (suffix)
    :param count: 数量，默认10
    :param stem: 词干
    :param suffix: 词尾
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        suffix2 = suffix
        if stem2 is None:
            stem2 = random.choice(stems)
        if suffix2 is None:
            suffix2 = random.choice(data_alchemy_suffix)
        name = to_str(stem2) + to_str(suffix2)
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_alchemies())



from typing import List
from name_genie.common import data_skill_numfix, data_skill_prefix, data_skill_suffix, data_shared_number, data_shared_clan, data_shared_action, data_shared_adj, data_shared_creature, data_shared_dao, data_shared_element, data_shared_gesture, data_shared_thing
from name_genie.util import to_str
import random

__all__ = ['get_skills']

stems = data_shared_number + data_shared_clan + data_shared_action + data_shared_adj + data_shared_creature + data_shared_dao + data_shared_element + data_shared_gesture + data_shared_thing


def get_skills(count: int = 10,
               stem: str | None = None,
               prefix: str | None = None,
               suffix: str | None = None,
               numfix: str | None = None,
               position: str | None = None) -> List[str]:
    """
    生成功法
    生成算法1：[numfix] + 路 + [prefix] + (stem) + (suffix)
    生成算法2：[prefix] + (stem) + (suffix) + [numfix] + 式
    :param count: 数量
    :param stem: 词干
    :param prefix: 前缀
    :param suffix: 后缀
    :param numfix: 数字
    :param position: 数字位置: 'left' | 'right'
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        prefix2 = prefix
        suffix2 = suffix
        numfix2 = numfix
        position2 = position
        if numfix2 is None and random.random() > 0.8:
            numfix2 = random.choice(data_skill_numfix)
        if prefix2 is None and random.random() > 0.8:
            prefix2 = random.choice(data_skill_prefix)
        if stem2 is None:
            stem2 = random.choice(stems)
        if suffix2 is None:
            suffix2 = random.choice(data_skill_suffix)
        if position2 is None:
            position2 = 'left' if random.random() > 0.5 else 'right'
        name = to_str(prefix2) + to_str(stem2) + to_str(suffix2)
        if numfix2 is not None and len(numfix2) > 0:
            if position2 == 'left':
                name = to_str(numfix2) + '路' + name
            else:
                name = name + to_str(numfix2) + '式'
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_skills())



from typing import List
from name_genie.common import data_material_state, data_material_suffix, data_shared_dao, data_shared_element, data_shared_color, data_shared_creature, data_shared_thing, data_shared_adj, data_shared_number, data_shared_gesture, data_shared_action
from name_genie.util import to_str
import random

__all__ = ['get_materials']


stems = data_shared_dao + data_shared_element + data_shared_color + data_shared_creature + data_shared_thing + data_shared_adj + data_shared_number + data_shared_gesture + data_shared_action


def get_materials(count: int = 10,
                  stem: str | None = None,
                  suffix: str | None = None,
                  state: str | None = None) -> List[str]:
    """
    生成材料
    生成算法：(stem) + (suffix) + [(state)]
    :param count: 数量
    :param stem: 词干
    :param suffix: 后缀
    :param state: 状态
    :return:
    """
    names: List[str] = []
    for i in range(count):
        stem2 = stem
        suffix2 = suffix
        state2 = state
        if stem2 is None:
            stem2 = random.choice(stems)
        if suffix2 is None:
            suffix2 = random.choice(data_material_suffix)
        if state2 is None and random.random() > 0.8:
            state2 = random.choice(data_material_state)
        name = to_str(stem2) + to_str(suffix2)
        if state2 is not None and len(state2) > 0:
            name += f'（{state2}）'
        names.append(name)
    return names


if __name__ == '__main__':
    print(get_materials())
